==> huaweicloudsdkgaussdbfornosql-3.1.137-py2.py3-none-any.whl: huaweicloudsdkgaussdbfornosql/v3/model/command_info.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CommandInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'origin_name': 'str',
        'name': 'str'
    }

    attribute_map = {
        'origin_name': 'origin_name',
        'name': 'name'
    }

    def __init__(self, origin_name=None, name=None):
        """CommandInfo

        The model defined in huaweicloud sdk

        :param origin_name: 原高危命令，当前支持的有：keys、flushdb、flushall、hgetall、hkeys、hvals、smembers
        :type origin_name: str
        :param name: 当前生效的命令名称，当为空时表示命令禁用，允许修改为30个字符以内数字、字母和下划线的组合
        :type name: str
        """
        
        

        self._origin_name = None
        self._name = None
        self.discriminator = None

        self.origin_name = origin_name
        self.name = name

    @property
    def origin_name(self):
        """Gets the origin_name of this CommandInfo.

        原高危命令，当前支持的有：keys、flushdb、flushall、hgetall、hkeys、hvals、smembers

        :return: The origin_name of this CommandInfo.
        :rtype: str
        """
        return self._origin_name

    @origin_name.setter
    def origin_name(self, origin_name):
        """Sets the origin_name of this CommandInfo.

        原高危命令，当前支持的有：keys、flushdb、flushall、hgetall、hkeys、hvals、smembers

        :param origin_name: The origin_name of this CommandInfo.
        :type origin_name: str
        """
        self._origin_name = origin_name

    @property
    def name(self):
        """Gets the name of this CommandInfo.

        当前生效的命令名称，当为空时表示命令禁用，允许修改为30个字符以内数字、字母和下划线的组合

        :return: The name of this CommandInfo.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CommandInfo.

        当前生效的命令名称，当为空时表示命令禁用，允许修改为30个字符以内数字、字母和下划线的组合

        :param name: The name of this CommandInfo.
        :type name: str
        """
        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CommandInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdbfornosql-3.1.149-py2.py3-none-any.whl: huaweicloudsdkgaussdbfornosql/v3/model/command_info.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CommandInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'origin_name': 'str',
        'name': 'str'
    }

    attribute_map = {
        'origin_name': 'origin_name',
        'name': 'name'
    }

    def __init__(self, origin_name=None, name=None):
        r"""CommandInfo

        The model defined in huaweicloud sdk

        :param origin_name: 原高危命令，当前支持的有：keys、flushdb、flushall、hgetall、hkeys、hvals、smembers
        :type origin_name: str
        :param name: 当前生效的命令名称，当为空时表示命令禁用，允许修改为30个字符以内数字、字母和下划线的组合
        :type name: str
        """
        
        

        self._origin_name = None
        self._name = None
        self.discriminator = None

        self.origin_name = origin_name
        self.name = name

    @property
    def origin_name(self):
        r"""Gets the origin_name of this CommandInfo.

        原高危命令，当前支持的有：keys、flushdb、flushall、hgetall、hkeys、hvals、smembers

        :return: The origin_name of this CommandInfo.
        :rtype: str
        """
        return self._origin_name

    @origin_name.setter
    def origin_name(self, origin_name):
        r"""Sets the origin_name of this CommandInfo.

        原高危命令，当前支持的有：keys、flushdb、flushall、hgetall、hkeys、hvals、smembers

        :param origin_name: The origin_name of this CommandInfo.
        :type origin_name: str
        """
        self._origin_name = origin_name

    @property
    def name(self):
        r"""Gets the name of this CommandInfo.

        当前生效的命令名称，当为空时表示命令禁用，允许修改为30个字符以内数字、字母和下划线的组合

        :return: The name of this CommandInfo.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        r"""Sets the name of this CommandInfo.

        当前生效的命令名称，当为空时表示命令禁用，允许修改为30个字符以内数字、字母和下划线的组合

        :param name: The name of this CommandInfo.
        :type name: str
        """
        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CommandInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
